@@ -23,7 +23,6 @@ import base64
 import errno
 import hashlib
 import logging
-import textwrap
 import zlib
 
 from debtcollector import removals
@@ -68,6 +67,7 @@ def _ensure_subprocess():
 
 def set_subprocess(_subprocess=None):
     """Set subprocess module to use.
+
     The subprocess could be eventlet.green.subprocess if using eventlet,
     or Python's subprocess otherwise.
     """
@@ -85,9 +85,7 @@ def _check_files_accessible(files):
     except IOError as e:
         # Catching IOError means there is an issue with
         # the given file.
-        err = _('Hit OSError in _process_communicate_handle_oserror()\n'
-                'Likely due to %(file)s: %(error)s') % {'file': try_file,
-                                                        'error': e.strerror}
+        err = try_file, e.strerror
         # Emulate openssl behavior, which returns with code 2 when
         # access to a file failed.
         retcode = OpensslCmsExitStatus.INPUT_FILE_READ_ERROR
@@ -103,7 +101,7 @@ def _process_communicate_handle_oserror(process, data, files):
     except OSError as e:
         if e.errno != errno.EPIPE:
             raise
-        # OSError with EPIPE only occurs with Python 2.6.x/old 2.7.x
+        # OSError with EPIPE only occurs with old Python 2.7.x versions
         # http://bugs.python.org/issue10963
 
         # The quick exit is typically caused by the openssl command not being
@@ -111,12 +109,25 @@ def _process_communicate_handle_oserror(process, data, files):
         retcode, err = _check_files_accessible(files)
         if process.stderr:
             msg = process.stderr.read()
-            err = err + msg.decode('utf-8')
+            if isinstance(msg, six.binary_type):
+                msg = msg.decode('utf-8')
+            if err:
+                err = (_('Hit OSError in '
+                         '_process_communicate_handle_oserror(): '
+                         '%(stderr)s\nLikely due to %(file)s: %(error)s') %
+                       {'stderr': msg,
+                        'file': err[0],
+                        'error': err[1]})
+            else:
+                err = (_('Hit OSError in '
+                         '_process_communicate_handle_oserror(): %s') % msg)
+
         output = ''
     else:
         retcode = process.poll()
         if err is not None:
-            err = err.decode('utf-8')
+            if isinstance(err, six.binary_type):
+                err = err.decode('utf-8')
 
     return output, err, retcode
 
@@ -180,11 +191,7 @@ def cms_verify(formatted, signing_cert_file_name, ca_file_name,
         else:
             raise exceptions.CertificateConfigError(err)
     elif retcode != OpensslCmsExitStatus.SUCCESS:
-        # NOTE(dmllr): Python 2.6 compatibility:
-        # CalledProcessError did not have output keyword argument
-        e = subprocess.CalledProcessError(retcode, 'openssl')
-        e.output = err
-        raise e
+        raise subprocess.CalledProcessError(retcode, 'openssl', output=err)
     return output
 
 
@@ -235,7 +242,7 @@ def token_to_cms(signed_text):
     copy_of_text = signed_text.replace('-', '/')
 
     lines = ['-----BEGIN CMS-----']
-    lines += textwrap.wrap(copy_of_text, 64)
+    lines += [copy_of_text[n:n + 64] for n in range(0, len(copy_of_text), 64)]
     lines.append('-----END CMS-----\n')
     return '\n'.join(lines)
 
