@@ -32,11 +32,11 @@ V2Token = v2.Token
 V3Token = v3.Token
 V3FederationToken = v3.V3FederationToken
 
-__all__ = ['DiscoveryList',
+__all__ = ('DiscoveryList',
            'FixtureValidationError',
            'V2Discovery',
            'V3Discovery',
            'V2Token',
            'V3Token',
            'V3FederationToken',
-           ]
+           )
